@@ -1,3 +1,4 @@
+import functools
 import os
 import shutil
 import tempfile
@@ -12,7 +13,7 @@ from django.core.files.storage import default_storage
 from django.core.files.temp import NamedTemporaryFile
 from django.core.management import call_command
 from django.db import models
-from django.test import TestCase
+from django.test import TestCase, override_settings
 from django.core.files.base import ContentFile
 
 from binary_database_files.models import File
@@ -22,6 +23,11 @@ from binary_database_files import utils
 
 DIR = os.path.abspath(os.path.split(__file__)[0])
 
+set_default_file_storage = functools.partial(
+    override_settings,
+    DEFAULT_FILE_STORAGE="binary_database_files.storage.DatabaseStorage",
+)
+
 
 class DatabaseFilesTestCase(TestCase):
     def setUp(self):
@@ -30,6 +36,7 @@ class DatabaseFilesTestCase(TestCase):
             shutil.rmtree(self.media_dir)
         os.makedirs(self.media_dir)
 
+    @set_default_file_storage()
     def test_adding_file(self):
 
         # Create default thing storing reference to file
@@ -76,7 +83,9 @@ class DatabaseFilesTestCase(TestCase):
         data0 = b"1234567890"
         test_file.write(data0)
         test_file.seek(0)
-        t = Thing.objects.create(upload=files.File(test_file),)
+        t = Thing.objects.create(
+            upload=files.File(test_file),
+        )
         self.assertEqual(File.objects.count(), 2)
         t = Thing.objects.get(pk=t.pk)
         self.assertEqual(t.upload.file.size, 10)
@@ -104,6 +113,7 @@ class DatabaseFilesTestCase(TestCase):
         self.assertEqual(default_storage.exists("i/special/test.txt"), False)
         self.assertEqual(os.path.isfile(test_fqfn), False)
 
+    @set_default_file_storage()
     def test_adding_extzipfile(self):
         # ZipExtFile advertises seek() but can raise UnsupportedOperation
         with ZipFile(os.path.join(DIR, "fixtures/test.zip")) as testzip:
@@ -117,9 +127,10 @@ class DatabaseFilesTestCase(TestCase):
                     self.assertEqual(uploaded.size, testzip.getinfo(filename).file_size)
                     self.assertEqual(BytesIO(uploaded.content).read(), testfile.read())
 
+    @set_default_file_storage()
     def test_adding_base64_file(self):
         image_content = open(os.path.join(DIR, "fixtures/test_image.png"), "rb").read()
-        base64_content = base64.encodestring(image_content).decode("ascii")
+        base64_content = base64.encodebytes(image_content).decode("ascii")
         q = File.objects.count()
         Thing.objects.create(upload=ContentFile(base64_content, name="test_image.png"))
         r = File.objects.count()
@@ -313,12 +324,7 @@ class DatabaseFilesTestCase(TestCase):
         self.assertTrue(t1.upload.storage.exists(t1.upload.name))
         os.remove(t1.upload.path)
         self.assertTrue(t1.upload.storage.exists(t1.upload.name))
-        self.assertEqual(
-            t1.upload.path, os.path.join(t1.upload.storage.location, "dummy.txt")
-        )
-        self.assertEqual(
-            t1.upload.path, Location1Thing.objects.get(pk=t1.pk).upload.path
-        )
+        self.assertRaises(NotImplementedError, lambda t1: t1.upload.path, t1)
         data2 = b"22222222"
         open(os.path.join(tmpdir, "dummy.txt"), "wb").write(data2)
         t2 = Location2Thing.objects.create(
@@ -326,13 +332,7 @@ class DatabaseFilesTestCase(TestCase):
         )
         os.remove(t2.upload.path)
         self.assertTrue(t2.upload.storage.exists(t2.upload.name))
-        self.assertEqual(
-            t2.upload.path, os.path.join(t2.upload.storage.location, "dummy.txt")
-        )
-        self.assertEqual(
-            t2.upload.path, Location2Thing.objects.get(pk=t2.pk).upload.path
-        )
-
+        self.assertRaises(NotImplementedError, lambda t2: t2.upload.path, t2)
         self.assertEqual(File.objects.count(), 2)
         self.assertEqual(Location2Thing.objects.get(pk=t2.pk).upload.file.read(), data2)
         self.assertEqual(Location1Thing.objects.get(pk=t1.pk).upload.file.read(), data1)
